==> dailycovid-1.1.2.tar.gz: dailycovid-1.1.2/dailycovid/american_states.py <==

def stateCodeKey():
    return {
        "AL":"ALABAMA",
    	"AK":"ALASKA",
    	"AZ":"ARIZONA",
    	"AR":"ARKANSAS",
    	"CA":"CALIFORNIA",
        "CO":"COLORADO",
    	"CT":"CONNECTICUT",
    	"DE":"DELAWARE",
    	"FL":"FLORIDA",
    	"GA":"GEORGIA",
        "GU":"GUAM",
        "HI":"HAWAII",
    	"ID":"IDAHO",
    	"IL":"ILLINOIS",
    	"IN":"INDIANA",
    	"IA":"IOWA",
    	"KS":"KANSAS",
        "KY":"KENTUCKY",
    	"LA":"LOUISIANA",
    	"ME":"MAINE",
    	"MD":"MARYLAND",
    	"MA":"MASSACHUSETTS",
        "MI":"MICHIGAN",
    	"MN":"MINNESOTA",
    	"MS":"MISSISSIPPI",
    	"MO":"MISSOURI",
    	"MT":"MONTANA",
        "NE":"NEBRASKA",
    	"NV":"NEVADA",
    	"NH":"NEW-HAMPSHIRE",
    	"NJ":"NEW-JERSEY",
    	"NM":"NEW-MEXICO",
        "NY":"NEW-YORK",
    	"NC":"NORTH-CAROLINA",
    	"ND":"NORTH-DAKOTA",
    	"OH":"OHIO",
    	"OK":"OKLAHOMA",
        "OR":"OREGON",
    	"PA":"PENNSYLVANIA",
        "PR":"PUERTO-RICO",
    	"RI":"RHODE-ISLAND",
    	"SC":"SOUTH-CAROLINA",
    	"SD":"SOUTH-DAKOTA",
        "TN":"TENNESSEE",
    	"TX":"TEXAS",
    	"UT":"UTAH",
    	"VT":"VERMONT",
        "VI":"VIRGIN-ISLANDS",
    	"VA":"VIRGINIA",
    	"WA":"WASHINGTON",
        "WV":"WEST-VIRGINIA",
    	"WI":"WISCONSIN",
    	"WY":"WYOMING"
    }


def stateCodesSet():
    return {
        "AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DC", "DE", "FL", "GA",
          "GU",
          "HI", "ID", "IL", "IN", "IA", "KS", "KY", "LA", "ME", "MD",
          "MA", "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ",
          "NM", "NY", "NC", "aND", "OH", "OK", "OR", "PA",
          "PR",
          "RI", "SC",
          "SD", "TN", "TX", "UT", "VT", "VA",
          "VI",
          "WA", "WV", "WI", "WY"
    }
##########################################################################################################

def stateFullNameKey():
    return {
        'ALABAMA': 'AL',
        'ALASKA': 'AK',
        'AMERICAN SAMOA': 'AS',
        'ARIZONA': 'AZ',
        'ARKANSAS': 'AR',
        'CALIFORNIA': 'CA',
        'COLORADO': 'CO',
        'CONNECTICUT': 'CT',
        'DELAWARE': 'DE',
        'DISTRICT OF COLUMBIA': 'DC',
        'FLORIDA': 'FL',
        'GEORGIA': 'GA',
        'GUAM': 'GU',
        'HAWAII': 'HI',
        'IDAHO': 'ID',
        'ILLINOIS': 'IL',
        'INDIANA': 'IN',
        'IOWA': 'IA',
        'KANSAS': 'KS',
        'KENTUCKY': 'KY',
        'LOUISIANA': 'LA',
        'MAINE': 'ME',
        'MARYLAND': 'MD',
        'MASSACHUSETTS': 'MA',
        'MICHIGAN': 'MI',
        'MINNESOTA': 'MN',
        'MISSISSIPPI': 'MS',
        'MISSOURI': 'MO',
        'MONTANA': 'MT',
        'NEBRASKA': 'NE',
        'NEVADA': 'NV',
        'NEW-HAMPSHIRE': 'NH',
        'NEW-JERSEY': 'NJ',
        'NEW-MEXICO': 'NM',
        'NEW-YORK': 'NY',
        'NORTH-CAROLINA': 'NC',
        'NORTH-DAKOTA': 'ND',
        'NORTHERN MARIANA ISLANDS':'MP',
        'OHIO': 'OH',
        'OKLAHOMA': 'OK',
        'OREGON': 'OR',
        'PENNSYLVANIA': 'PA',
        'PUERTO-RICO': 'PR',
        'RHODE-ISLAND': 'RI',
        'SOUTH-CAROLINA': 'SC',
        'SOUTH-DAKOTA': 'SD',
        'TENNESSEE': 'TN',
        'TEXAS': 'TX',
        'UTAH': 'UT',
        'VERMONT': 'VT',
        'VIRGIN-ISLANDS': 'VI',
        'VIRGINIA': 'VA',
        'WASHINGTON': 'WA',
        'WEST-VIRGINIA': 'WV',
        'WISCONSIN': 'WI',
        'WYOMING': 'WY'
    }

def statesFullNameSet():
    return {
        "ALASKA",
    	"ALABAMA",
    	"ARKANSAS",
    	"AMERICAN SAMOA",
    	"ARIZONA",
    	"CALIFORNIA",
    	"COLORADO",
    	"CONNECTICUT",
    	"DISTRICT OF COLUMBIA",
    	"DELAWARE",
    	"FLORIDA",
    	"GEORGIA",
    	"GUAM",
    	"HAWAII",
    	"IOWA",
    	"IDAHO",
    	"ILLINOIS",
    	"INDIANA",
    	"KANSAS",
    	"KENTUCKY",
    	"LOUISIANA",
    	"MASSACHUSETTS",
    	"MARYLAND",
    	"MAINE",
    	"MICHIGAN",
    	"MINNESOTA",
    	"MISSOURI",
    	"MISSISSIPPI",
    	"MONTANA",
    	"NORTH-CAROLINA",
    	"NORTH-DAKOTA",
    	"NEBRASKA",
    	"NEW-HAMPSHIRE",
    	"NEW-JERSEY",
    	"NEW-MEXICO",
    	"NEVADA",
    	"NEW-YORK",
    	"OHIO",
    	"OKLAHOMA",
    	"OREGON",
    	"PENNSYLVANIA",
    	"PUERTO-RICO",
    	"RHODE-ISLAND",
    	"SOUTH-CAROLINA",
    	"SOUTH-DAKOTA",
    	"TENNESSEE",
    	"TEXAS",
    	"UTAH",
    	"VIRGINIA",
    	"VIRGIN-ISLANDS",
    	"VERMONT",
    	"WASHINGTON",
    	"WISCONSIN",
    	"WEST-VIRGINIA",
    	"WYOMING"
    }

==> dailycovid-1.2.3.tar.gz: dailycovid-1.2.3/dailycovid/american_states.py <==

def stateCodeKey():
    return {
        "AL":"ALABAMA",
    	"AK":"ALASKA",
    	"AZ":"ARIZONA",
    	"AR":"ARKANSAS",
    	"CA":"CALIFORNIA",
        "CO":"COLORADO",
    	"CT":"CONNECTICUT",
        "DC":"DC",
    	"DE":"DELAWARE",
    	"FL":"FLORIDA",
    	"GA":"GEORGIA",
        "GU":"GUAM",
        "HI":"HAWAII",
    	"ID":"IDAHO",
    	"IL":"ILLINOIS",
    	"IN":"INDIANA",
    	"IA":"IOWA",
    	"KS":"KANSAS",
        "KY":"KENTUCKY",
    	"LA":"LOUISIANA",
    	"ME":"MAINE",
    	"MD":"MARYLAND",
    	"MA":"MASSACHUSETTS",
        "MI":"MICHIGAN",
    	"MN":"MINNESOTA",
    	"MS":"MISSISSIPPI",
    	"MO":"MISSOURI",
    	"MT":"MONTANA",
        "NE":"NEBRASKA",
    	"NV":"NEVADA",
    	"NH":"NEW-HAMPSHIRE",
    	"NJ":"NEW-JERSEY",
    	"NM":"NEW-MEXICO",
        "NY":"NEW-YORK",
    	"NC":"NORTH-CAROLINA",
    	"ND":"NORTH-DAKOTA",
    	"OH":"OHIO",
    	"OK":"OKLAHOMA",
        "OR":"OREGON",
    	"PA":"PENNSYLVANIA",
        "PR":"PUERTO-RICO",
    	"RI":"RHODE-ISLAND",
    	"SC":"SOUTH-CAROLINA",
    	"SD":"SOUTH-DAKOTA",
        "TN":"TENNESSEE",
    	"TX":"TEXAS",
    	"UT":"UTAH",
    	"VT":"VERMONT",
        "VI":"VIRGIN-ISLANDS",
    	"VA":"VIRGINIA",
    	"WA":"WASHINGTON",
        "WV":"WEST-VIRGINIA",
    	"WI":"WISCONSIN",
    	"WY":"WYOMING"
    }


def stateCodesSet():
    return {
        "AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DC", "DE", "FL", "GA",
          "GU",
          "HI", "ID", "IL", "IN", "IA", "KS", "KY", "LA", "ME", "MD",
          "MA", "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ",
          "NM", "NY", "NC", "ND", "OH", "OK", "OR", "PA",
          "PR",
          "RI", "SC",
          "SD", "TN", "TX", "UT", "VT", "VA",
          "VI",
          "WA", "WV", "WI", "WY"
    }
##########################################################################################################

def stateFullNameKey():
    return {
        'ALABAMA': 'AL',
        'ALASKA': 'AK',
        'AMERICAN SAMOA': 'AS',
        'ARIZONA': 'AZ',
        'ARKANSAS': 'AR',
        'CALIFORNIA': 'CA',
        'COLORADO': 'CO',
        'CONNECTICUT': 'CT',
        'DELAWARE': 'DE',
        'DISTRICT OF COLUMBIA': 'DC',
        'FLORIDA': 'FL',
        'GEORGIA': 'GA',
        'GUAM': 'GU',
        'HAWAII': 'HI',
        'IDAHO': 'ID',
        'ILLINOIS': 'IL',
        'INDIANA': 'IN',
        'IOWA': 'IA',
        'KANSAS': 'KS',
        'KENTUCKY': 'KY',
        'LOUISIANA': 'LA',
        'MAINE': 'ME',
        'MARYLAND': 'MD',
        'MASSACHUSETTS': 'MA',
        'MICHIGAN': 'MI',
        'MINNESOTA': 'MN',
        'MISSISSIPPI': 'MS',
        'MISSOURI': 'MO',
        'MONTANA': 'MT',
        'NEBRASKA': 'NE',
        'NEVADA': 'NV',
        'NEW-HAMPSHIRE': 'NH',
        'NEW-JERSEY': 'NJ',
        'NEW-MEXICO': 'NM',
        'NEW-YORK': 'NY',
        'NORTH-CAROLINA': 'NC',
        'NORTH-DAKOTA': 'ND',
        'NORTHERN MARIANA ISLANDS':'MP',
        'OHIO': 'OH',
        'OKLAHOMA': 'OK',
        'OREGON': 'OR',
        'PENNSYLVANIA': 'PA',
        'PUERTO-RICO': 'PR',
        'RHODE-ISLAND': 'RI',
        'SOUTH-CAROLINA': 'SC',
        'SOUTH-DAKOTA': 'SD',
        'TENNESSEE': 'TN',
        'TEXAS': 'TX',
        'UTAH': 'UT',
        'VERMONT': 'VT',
        'VIRGIN-ISLANDS': 'VI',
        'VIRGINIA': 'VA',
        'WASHINGTON': 'WA',
        'WEST-VIRGINIA': 'WV',
        'WISCONSIN': 'WI',
        'WYOMING': 'WY'
    }

def statesFullNameSet():
    return {
        "ALASKA",
    	"ALABAMA",
    	"ARKANSAS",
    	"AMERICAN SAMOA",
    	"ARIZONA",
    	"CALIFORNIA",
    	"COLORADO",
    	"CONNECTICUT",
    	"DISTRICT OF COLUMBIA",
    	"DELAWARE",
    	"FLORIDA",
    	"GEORGIA",
    	"GUAM",
    	"HAWAII",
    	"IOWA",
    	"IDAHO",
    	"ILLINOIS",
    	"INDIANA",
    	"KANSAS",
    	"KENTUCKY",
    	"LOUISIANA",
    	"MASSACHUSETTS",
    	"MARYLAND",
    	"MAINE",
    	"MICHIGAN",
    	"MINNESOTA",
    	"MISSOURI",
    	"MISSISSIPPI",
    	"MONTANA",
    	"NORTH-CAROLINA",
    	"NORTH-DAKOTA",
    	"NEBRASKA",
    	"NEW-HAMPSHIRE",
    	"NEW-JERSEY",
    	"NEW-MEXICO",
    	"NEVADA",
    	"NEW-YORK",
    	"OHIO",
    	"OKLAHOMA",
    	"OREGON",
    	"PENNSYLVANIA",
    	"PUERTO-RICO",
    	"RHODE-ISLAND",
    	"SOUTH-CAROLINA",
    	"SOUTH-DAKOTA",
    	"TENNESSEE",
    	"TEXAS",
    	"UTAH",
    	"VIRGINIA",
    	"VIRGIN-ISLANDS",
    	"VERMONT",
    	"WASHINGTON",
    	"WISCONSIN",
    	"WEST-VIRGINIA",
    	"WYOMING"
    }
